==> k3d-5.0.0.tar.gz: k3d-5.0.0/CONTRIBUTING.md <==
# Contributing Guidelines

Hi there! Welcome to the k3d and Rancher Community!
We welcome everyone who likes to use and improve our software.

## Getting Started

Before starting to work with and on k3d, please read and understand our [**Code of Conduct**](./CODE_OF_CONDUCT.md).

Get an Overview of the k3d project in the documentation: [k3d.io/internals/project](https://k3d.io/internals/project)

Before opening an issue or a Pull-Request, please use GitHub's search function to check whether something similar is already in process and hook in there instead.

## Get Recognized

We want to foster a collaborative environment, where every contribution is welcomed and recognized.

If you want to show up in our Contributors section, please make use of the @all-contributors bot integrated with this repository.

Here's a full guide on using the bot: <https://allcontributors.org/docs/en/bot/usage>.
The simplest way to use it is (in a comment on an issue or a pull-request): `@all-contributors please add <username> for <contributions>`, where `<contributions>` is a [list of contributions](https://allcontributors.org/docs/en/emoji-key).

Here's an [example comment on a PR](https://github.com/rancher/k3d/pull/368#issuecomment-704320376) to tell the bot to add @zeerorg (who had the initial idea for k3s in docker) to the list of contributors for the ideas and code he added:

> @all-contributors please add @zeerorg for ideas and code

The bot will open a PR to add the user to the list and posts the link as a follow-up comment on the issue/PR.

==> k3d-5.4.0.tar.gz: k3d-5.4.0/CONTRIBUTING.md <==
# Contributing Guidelines

Hi there! Welcome to the k3d and Rancher Community!
We welcome everyone who likes to use and improve our software.

## Getting Started

Before starting to work with and on k3d, please read and understand our [**Code of Conduct**](./CODE_OF_CONDUCT.md).

Get an Overview of the k3d project in the documentation: [k3d.io/internals/project](https://k3d.io/internals/project)

Before opening an issue or a Pull-Request, please use GitHub's search function to check whether something similar is already in process and hook in there instead.

## Get Recognized

We want to foster a collaborative environment, where every contribution is welcomed and recognized.

If you want to show up in our Contributors section, please make use of the @all-contributors bot integrated with this repository.

Here's a full guide on using the bot: <https://allcontributors.org/docs/en/bot/usage>.
The simplest way to use it is (in a comment on an issue or a pull-request): `@all-contributors please add <username> for <contributions>`, where `<contributions>` is a [list of contributions](https://allcontributors.org/docs/en/emoji-key).

Here's an [example comment on a PR](https://github.com/k3d-io/k3d/pull/368#issuecomment-704320376) to tell the bot to add @zeerorg (who had the initial idea for k3s in docker) to the list of contributors for the ideas and code he added:

> @all-contributors please add @zeerorg for ideas and code

The bot will open a PR to add the user to the list and posts the link as a follow-up comment on the issue/PR.
